@@ -12,6 +12,17 @@ describe "any_not_empty extension" do
     @ds.db.sqls.must_equal ["SELECT 1 AS one FROM t LIMIT 1"]
   end
 
+  it "should use a limited query if called on a model" do
+    @c = Sequel::Model(@ds)
+    @ds.db.sqls
+    @ds.db.fetch = {:one=>1}
+    @c.any?.must_equal true
+    @ds.db.sqls.must_equal ["SELECT 1 AS one FROM t LIMIT 1"]
+    @ds.db.fetch = []
+    @c.any?.must_equal false
+    @ds.db.sqls.must_equal ["SELECT 1 AS one FROM t LIMIT 1"]
+  end
+
   it "should use default behavior if block is given" do
     @ds.with_fetch(:one=>1).any?{|x| x[:one] == 1}.must_equal true
     @ds.db.sqls.must_equal ["SELECT * FROM t"]
