@@ -42,7 +42,7 @@ describe "pg_auto_parameterize extension" do
       merge_update(:i1=>Sequel[:i1]+:i2+10, :a=>Sequel[:a]+:b+20).
       merge
     sqls = @db.sqls
-    sqls.must_equal ['MERGE INTO "table" USING "m2" ON ("i1" = "i2") WHEN NOT MATCHED AND ("b" > $1::int4) THEN DO NOTHING WHEN NOT MATCHED THEN INSERT  ("i1", "a") VALUES ("i2", ("b" + $2::int4)) WHEN MATCHED AND ("a" > $1::int4) THEN DO NOTHING WHEN MATCHED AND ("a" > $3::int4) THEN DELETE WHEN MATCHED THEN UPDATE SET "i1" = ("i1" + "i2" + $4::int4), "a" = ("a" + "b" + $5::int4)']
+    sqls.must_equal ['MERGE INTO "table" USING "m2" ON ("i1" = "i2") WHEN NOT MATCHED AND ("b" > $1::int4) THEN DO NOTHING WHEN NOT MATCHED THEN INSERT ("i1", "a") VALUES ("i2", ("b" + $2::int4)) WHEN MATCHED AND ("a" > $1::int4) THEN DO NOTHING WHEN MATCHED AND ("a" > $3::int4) THEN DELETE WHEN MATCHED THEN UPDATE SET "i1" = ("i1" + "i2" + $4::int4), "a" = ("a" + "b" + $5::int4)']
     sqls[0].args.must_equal [50, 11, 30, 10, 20]
   end
 
@@ -63,6 +63,14 @@ describe "pg_auto_parameterize extension" do
     sqls[1].must_equal 'INSERT INTO "table" ("a") VALUES ' + args[0...40].map{|i| "($#{i}::int4)"}.join(', ') + " -- args: #{args[40...80].inspect}"
   end
 
+  it "should not split inserts of multiple rows to 40 at a time with no_auto_parameterize" do
+    args = (1...81).to_a
+    @db[:table].no_auto_parameterize.import([:a], args)
+    sqls = @db.sqls
+    sqls.size.must_equal 1
+    sqls[0].must_equal 'INSERT INTO "table" ("a") VALUES ' + args.map{|i| "(#{i})"}.join(', ')
+  end
+
   it "should automatically parameterize queries strings, blobs, numerics, dates, and times" do
     ds = @db[:table]
     pr = proc do |sql, *args|
@@ -89,6 +97,25 @@ describe "pg_auto_parameterize extension" do
     pr.call('SELECT * FROM "table" WHERE ("a" = $1::timestamp)', Time.utc(2012, 1, 2, 3, 4, 5))
     pr.call('SELECT * FROM "table" WHERE ("a" = 1)', Sequel.lit('1'), :nil)
     pr.call('SELECT * FROM "table" WHERE ("a" = "b")', :b, :nil)
+    pr.call('SELECT * FROM "table" WHERE ("a" = "b")', Sequel.identifier(:b), :nil)
+  end
+
+  it "should automatically parameterize when using explain or analyze" do
+    ds = @db[:table].where(:a => 1)
+    ds.explain
+    ds.analyze
+    @db.sqls.must_equal [
+      'EXPLAIN SELECT * FROM "table" WHERE ("a" = $1::int4) -- args: [1]',
+      'EXPLAIN (ANALYZE) SELECT * FROM "table" WHERE ("a" = $1::int4) -- args: [1]'
+    ]
+
+    ds = ds.no_auto_parameterize
+    ds.explain
+    ds.analyze
+    @db.sqls.must_equal [
+      'EXPLAIN SELECT * FROM "table" WHERE ("a" = 1)',
+      'EXPLAIN (ANALYZE) SELECT * FROM "table" WHERE ("a" = 1)'
+    ]
   end
 
   it "should automatically parameterize and not typecast Sequel::SQL::Cast values" do
@@ -236,6 +263,14 @@ describe "pg_auto_parameterize extension" do
     sql = @db[:table].where(:a=>[1,nil,3]).sql
     sql.must_equal 'SELECT * FROM "table" WHERE ("a" = ANY(CAST($1 AS int8[])))'
     sql.args.must_equal ['{1,NULL,3}']
+
+    sql = @db[:table].where(:a=>Set[1,2,3]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" = ANY(CAST($1 AS int8[])))'
+    sql.args.must_equal ['{1,2,3}']
+
+    sql = @db[:table].where(:a=>Set[1,nil,3]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" = ANY(CAST($1 AS int8[])))'
+    sql.args.must_equal ['{1,NULL,3}']
   end
 
   it "should automatically switch column NOT IN (int, ...) to column != ALL($) with parameter" do
@@ -246,15 +281,31 @@ describe "pg_auto_parameterize extension" do
     sql = @db[:table].exclude(:a=>[1,nil,3]).sql
     sql.must_equal 'SELECT * FROM "table" WHERE ("a" != ALL(CAST($1 AS int8[])))'
     sql.args.must_equal ['{1,NULL,3}']
+
+    sql = @db[:table].exclude(:a=>Set[1,2,3]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" != ALL(CAST($1 AS int8[])))'
+    sql.args.must_equal ['{1,2,3}']
+
+    sql = @db[:table].exclude(:a=>Set[1,nil,3]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" != ALL(CAST($1 AS int8[])))'
+    sql.args.must_equal ['{1,NULL,3}']
   end
 
   it "should not convert IN/NOT IN expressions that don't use integers" do
-    sql = @db[:table].where([:a, :b]=>%w[1 2]).sql
-    sql.must_equal 'SELECT * FROM "table" WHERE (("a", "b") IN ($1, $2))'
+    sql = @db[:table].where(:a=>%w[1 2]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" IN ($1, $2))'
     sql.args.must_equal %w[1 2]
 
-    sql = @db[:table].exclude([:a, :b]=>%w[1 2]).sql
-    sql.must_equal 'SELECT * FROM "table" WHERE (("a", "b") NOT IN ($1, $2))'
+    sql = @db[:table].exclude(:a=>%w[1 2]).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" NOT IN ($1, $2))'
+    sql.args.must_equal %w[1 2]
+
+    sql = @db[:table].where(:a=>Set['1', '2']).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" IN ($1, $2))'
+    sql.args.must_equal %w[1 2]
+
+    sql = @db[:table].exclude(:a=>Set['1', '2']).sql
+    sql.must_equal 'SELECT * FROM "table" WHERE ("a" NOT IN ($1, $2))'
     sql.args.must_equal %w[1 2]
   end
 
@@ -351,16 +402,25 @@ describe "pg_auto_parameterize extension" do
     sql.args.must_equal [v]
   end
 
-  it "should automatically parameterize pg_multirange values" do
+  it "should automatically parameterize pg_multirange values if they are parameterizable" do
     @db.extension :pg_multirange
     v = Sequel.pg_multirange([1..2, 5..6], :int4multirange)
     sql = @db[:table].insert_sql(v)
     sql.must_equal 'INSERT INTO "table" VALUES ($1::int4multirange)'
-    sql.args.length.must_equal 1
     sql.args.must_equal [v]
+
+    v = Sequel.pg_multirange([Sequel::Postgres::PGRange.new(1, nil, :db_type => :int4range)], :int4multirange)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES ($1::int4multirange)'
+    sql.args.must_equal [v]
+
+    v = Sequel.pg_multirange([Sequel::Postgres::PGRange.new(1, :en, :db_type => :int4range)], :int4multirange)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES (int4multirange(int4range($1::int4,"en",$2)))'
+    sql.args.must_equal [1, "[]"]
   end
 
-  it "should automatically parameterize pg_range values" do
+  it "should automatically parameterize pg_range values if they are parameterizable" do
     @db.extension :pg_range
     v = Sequel.pg_range(1..2, :int4range)
     sql = @db[:table].insert_sql(v)
@@ -371,6 +431,36 @@ describe "pg_auto_parameterize extension" do
     sql = @db[:table].insert_sql(v)
     sql.must_equal 'INSERT INTO "table" VALUES ($1)'
     sql.args.must_equal ['[1,2]']
+
+    v = Sequel::Postgres::PGRange.new(1, nil, :db_type => :int4range)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES ($1::int4range)'
+    sql.args.must_equal [v]
+
+    v = Sequel::Postgres::PGRange.new(1, nil)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES ($1)'
+    sql.args.must_equal ['[1,]']
+
+    v = Sequel::Postgres::PGRange.new(nil, 2, :db_type => :int4range)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES ($1::int4range)'
+    sql.args.must_equal [v]
+
+    v = Sequel::Postgres::PGRange.new(nil, 2, :exclude_begin => true, :exclude_end => true)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES ($1)'
+    sql.args.must_equal ['(,2)']
+
+    v = Sequel::Postgres::PGRange.new(:st, 2, :db_type => :int4range)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES (int4range("st",$1::int4,$2))'
+    sql.args.must_equal [2, '[]']
+
+    v = Sequel::Postgres::PGRange.new(1, :en, :exclude_begin => true, :exclude_end=> true, :db_type => :int4range)
+    sql = @db[:table].insert_sql(v)
+    sql.must_equal 'INSERT INTO "table" VALUES (int4range($1::int4,"en",$2))'
+    sql.args.must_equal [1, '()']
   end
 
   it "should automatically parameterize pg_row values if parts are automatically parameterizable" do
@@ -417,9 +507,34 @@ describe "pg_auto_parameterize extension" do
     sql.args.frozen?.must_equal true
   end
 
-  it "should not support placeholder literalizers unless auto parameterization is disabled" do
-    @db[:table].supports_placeholder_literalizer?.must_be_nil
-    @db[:table].no_auto_parameterize.supports_placeholder_literalizer?.must_equal true
+  it "should support placeholder literalizers with existing arguments when not auto parametizing" do
+    ds = @db[:table].having(:a=>5).no_auto_parameterize
+    3.times do |i|
+      ds.first(:b=>i)
+    end
+    @db.sqls.must_equal ["SELECT * FROM \"table\" WHERE (\"b\" = 0) HAVING (\"a\" = 5) LIMIT 1",
+      "SELECT * FROM \"table\" WHERE (\"b\" = 1) HAVING (\"a\" = 5) LIMIT 1",
+      "SELECT * FROM \"table\" WHERE (\"b\" = 2) HAVING (\"a\" = 5) LIMIT 1"]
+  end
+
+  it "should support placeholder literalizers with existing arguments" do
+    ds = @db[:table].having(:a=>5)
+    3.times do |i|
+      ds.first(:b=>i)
+    end
+    @db.sqls.must_equal ["SELECT * FROM \"table\" WHERE (\"b\" = $1::int4) HAVING (\"a\" = $2::int4) LIMIT 1 -- args: [0, 5]",
+      "SELECT * FROM \"table\" WHERE (\"b\" = $1::int4) HAVING (\"a\" = $2::int4) LIMIT 1 -- args: [1, 5]",
+      "SELECT * FROM \"table\" WHERE (\"b\" = $2::int4) HAVING (\"a\" = $1::int4) LIMIT 1 -- args: [5, 2]"]
+  end
+
+  it "should support placeholder literalizers without arguments" do
+    ds = @db[:table]
+    3.times do |i|
+      ds.first(:b=>i)
+    end
+    @db.sqls.must_equal ["SELECT * FROM \"table\" WHERE (\"b\" = $1::int4) LIMIT 1 -- args: [0]",
+      "SELECT * FROM \"table\" WHERE (\"b\" = $1::int4) LIMIT 1 -- args: [1]",
+      "SELECT * FROM \"table\" WHERE (\"b\" = $1::int4) LIMIT 1 -- args: [2]"]
   end
 
   it "should not automatically parameterize if no_auto_parameterize is used" do
