@@ -1,4 +1,4 @@
-require_relative "spec_helper"
+require_relative "../adapters/spec_helper"
 
 describe "Database schema parser" do
   after do
@@ -175,16 +175,19 @@ describe "Database schema parser" do
     DB.schema(:items).first.last[:db_type].must_equal db_type
   end
 
-  int_types = [Integer, :Bignum]
+  int_types = [Integer, :Bignum, [Numeric, {:size=>7}]]
+  decimal_types = [[Numeric, {:size=>[10, 2]}], [BigDecimal, {:size=>[8, 3]}]]
 
   case DB.database_type
   when :postgres
     int_types.concat([:smallint, :int2, :int4, :int8])
+    decimal_types.concat(["numeric(3, 5)", "numeric(3, -2)"]) if DB.server_version >= 150000
   when :mysql
     if DB.send(:supports_check_constraints?)
       int_types.concat([:tinyint, :smallint, :mediumint, 'int(9)', 'tinyint(2)', "integer unsigned", "bigint unsigned", "tinyint unsigned", "smallint unsigned", "mediumint unsigned", 'int(9) unsigned', 'tinyint(2) unsigned'])
     else
       int_types.clear 
+      decimal_types.clear
     end
   when :mssql, :h2, :hsqldb
     int_types.concat([:smallint, :tinyint])
@@ -192,24 +195,33 @@ describe "Database schema parser" do
     int_types.concat([:smallint])
   when :sqlanywhere
     int_types.concat([:tinyint])
-  when :sqlite, :oracle
-    # SQLite doesn't enforce integer type values, even on strict tables.
-    # Oracle only has a number type with variable precision, not a standard integer type.
+  when :sqlite
+    # SQLite doesn't enforce integer/decimal type values, even on strict tables.
     int_types.clear
+    decimal_types.clear
+  when :oracle
+    # Oracle only has a number type with variable precision, not a standard integer type.
+    int_types = [[Numeric, {:size=>7}]]
   end
 
-  if int_types.empty?
-    it "should not parse maximum and minimum values for integer columns" do
-      DB.create_table!(:items){Integer :a}
-      sch = DB.schema(:items).first.last
-      sch.keys.wont_include :max_value
-      sch.keys.wont_include :min_value
+  {
+    Integer=>int_types,
+    [Numeric, {:size=>[10,2]}]=>decimal_types,
+    Numeric=>[1],
+  }.each do |type, types|
+    if types.empty?
+      it "should not parse maximum and minimum values for #{type} columns" do
+        DB.create_table!(:items){column :a, *type}
+        sch = DB.schema(:items).first.last
+        sch.keys.wont_include :max_value
+        sch.keys.wont_include :min_value
+      end
     end
   end
 
   int_types.each do |type|
     it "should correctly parse maximum and minimum values for #{type} columns" do
-      DB.create_table!(:items){column :a, type}
+      DB.create_table!(:items){column :a, *type}
       sch = DB.schema(:items).first.last
       max = sch[:max_value]
       min = sch[:min_value]
@@ -220,7 +232,44 @@ describe "Database schema parser" do
       proc{ds.insert(min-1)}.must_raise(Sequel::DatabaseError, Sequel::InvalidValue)
       ds.insert(max)
       ds.insert(min)
-      ds.select_order_map(:a).must_equal [min, max]
+      if DB.adapter_scheme == :ibmdb || DB.adapter_scheme == :odbc
+        ds.select_order_map(Sequel.cast(:a, String)).map{|x| Integer(x)}.must_equal [min, max]
+      else
+        ds.select_order_map(:a).must_equal [min, max]
+      end
+    end
+  end
+
+  decimal_types.each do |type|
+    it "should correctly parse maximum and minimum values for #{type} columns" do
+      DB.create_table!(:items){column :a, *type}
+      sch = DB.schema(:items).first.last
+      max = sch[:max_value]
+      min = sch[:min_value]
+      max.must_be_kind_of BigDecimal
+      min.must_be_kind_of BigDecimal
+      ds = DB[:items]
+
+      inc = case max.to_s('F')
+      when /\A9+\.0\z/
+        1
+      when /\A(?:0|9+)\.(0*9+)\z/
+        BigDecimal(1)/(10**$1.length)
+      when /\A(?:9+)(0+)\.0+\z/
+        BigDecimal(1) * (10**$1.length)
+      else
+        raise "spec error, cannot parse maximum value"
+      end
+
+      proc{ds.insert(max+inc)}.must_raise(Sequel::DatabaseError, Sequel::InvalidValue)
+      proc{ds.insert(min-inc)}.must_raise(Sequel::DatabaseError, Sequel::InvalidValue)
+      ds.insert(max)
+      ds.insert(min)
+      if DB.adapter_scheme == :oracle || DB.adapter_scheme == :odbc
+        ds.select_order_map(:a).map{|x| BigDecimal(x.to_s)}.must_equal [min, max]
+      else
+        ds.select_order_map(:a).must_equal [min, max]
+      end
     end
   end
 
@@ -335,13 +384,32 @@ describe "Database foreign key parsing" do
 end if DB.supports_foreign_key_parsing?
 
 describe "Database" do
-  after do
+  before do
     DB.drop_table(:items_temp) rescue nil
   end
-
-  it "should create temporary tables without raising an exception" do
+  after(:all) do
     DB.disconnect
-    DB.create_table!(:items_temp, :temp=>true){Integer :number}
+  end
+
+  it "should allow creation and use of temporary tables" do
+    DB.synchronize do
+      DB.create_table!(:items_temp, :temp=>true){Integer :number}
+      table = case DB.database_type
+      when :mssql
+        Sequel.lit("#items_temp")
+      when :derby, :db2
+        Sequel[:session][:items_temp]
+      else
+        :items_temp
+      end
+      DB.from(table).all.must_equal []
+    end
+  end
+
+  cspecify "should raise when trying to create a schema qualified temporary table in an invalid schema", [:mariadb?.to_proc, :mysql] do
+    proc do
+      DB.create_table(Sequel[:invalid_temp_schema][:items_temp], :temp=>true){Integer :number}
+    end.must_raise(DB.database_type == :mssql ? Sequel::Error : Sequel::DatabaseError)
   end
 end
 
@@ -543,6 +611,13 @@ describe "Database schema modifiers" do
     @db.alter_table(:items2){drop_constraint :foo_pk, :type=>:primary_key}
   end
 
+  it "should be able to specify constraint names for column constraints using :primary_key and :unique option hashes" do
+    @db.create_table!(:items2){primary_key :id, :primary_key=>{:name=>:foo_pk}}
+    @db.create_table!(:items){Integer :id, :unique=>{:name=>:foo_uk}, :null=>false}
+    @db.alter_table(:items){drop_constraint :foo_uk, :type=>:unique}
+    @db.alter_table(:items2){drop_constraint :foo_pk, :type=>:primary_key}
+  end
+
   it "should handle foreign keys correctly when creating tables" do
     @db.create_table!(:items) do 
       primary_key :id
@@ -555,6 +630,16 @@ describe "Database schema modifiers" do
     @ds.columns!.must_equal [:id, :item_id]
   end
 
+  it "should handle foreign keys with explicit :key option with symbol value" do
+    @db.create_table!(:items) do 
+      primary_key :id
+      foreign_key :item_id, :items, :key=>:id
+    end
+    @db.table_exists?(:items).must_equal true
+    @db.schema(:items, :reload=>true).map{|x| x.first}.must_equal [:id, :item_id]
+    @ds.columns!.must_equal [:id, :item_id]
+  end
+
   it "should add columns to tables correctly" do
     @db.create_table!(:items){Integer :number}
     @ds.insert(:number=>10)
