@@ -15,6 +15,12 @@ describe Sequel::Model::Associations::AssociationReflection, "#associated_class"
     @c.association_reflection(:c).associated_class.must_equal ParParent
   end
 
+  it "should cache result of hash method on initialization" do
+    @c.many_to_one :c, :class=>ParParent
+    stored = @c.association_reflection(:c)[:_hash]
+    @c.association_reflection(:c).hash.must_equal stored
+  end
+
   it "should use the :class value if present" do
     @c.many_to_one :c, :class=>@c
     @c.one_to_many :cs, :class=>@c
@@ -40,12 +46,21 @@ describe Sequel::Model::Associations::AssociationReflection, "#associated_class"
     ParParent.many_to_one :c
     ParParent.association_reflection(:c).inspect.must_equal "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c>"
     ParParent.many_to_one :c, :class=>ParParent
-    ParParent.association_reflection(:c).inspect.must_equal "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, :class=>ParParent>"
+    [
+      "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, :class=>ParParent>",
+      "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, class: ParParent>"
+     ].must_include(ParParent.association_reflection(:c).inspect)
     ParParent.many_to_one :c, :class=>ParParent, :key=>:c_id
-    ParParent.association_reflection(:c).inspect.must_equal "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, :key=>:c_id, :class=>ParParent>"
+    [
+      "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, :key=>:c_id, :class=>ParParent>",
+      "#<Sequel::Model::Associations::ManyToOneAssociationReflection ParParent.many_to_one :c, key: :c_id, class: ParParent>"
+     ].must_include(ParParent.association_reflection(:c).inspect)
 
     @c.one_to_many :foos do |ds| ds end
-    @c.association_reflection(:foos).inspect.must_equal "#<Sequel::Model::Associations::OneToManyAssociationReflection #{@c.to_s}.one_to_many :foos, :block=>#{@c.association_reflection(:foos)[:block].inspect}>"
+    [
+      "#<Sequel::Model::Associations::OneToManyAssociationReflection #{@c.to_s}.one_to_many :foos, :block=>#{@c.association_reflection(:foos)[:block].inspect}>",
+      "#<Sequel::Model::Associations::OneToManyAssociationReflection #{@c.to_s}.one_to_many :foos, block: #{@c.association_reflection(:foos)[:block].inspect}>"
+    ].must_include(@c.association_reflection(:foos).inspect)
   end
 
   it "should figure out the class if the :class value is not present" do
